from tests import app


@app.route("/error-assert-variable")
def error_assert_variable():
    return ""
